# pyrailroad : Railroad-Diagram Generator

Python package to draw railroad (or syntax) diagrams. Based largely on [railroad-diagrams](https://github.com/tabatkins/railroad-diagrams) and the [partial parser](https://github.com/speced/bikeshed/blob/main/bikeshed/railroadparser.py[) by [tbatkins](https://github.com/tabatkins)

Browse the [documentation](https://epithumia.github.io/pyrailroad/)
